@@ -5,6 +5,6 @@ from formats_common import *
 enable = False
 format = "GettextMo"
 description = "Gettext Binary (mo)"
-extentions = [".mo"]
-readOptions = []
-writeOptions = []
+extensions = (".mo",)
+singleFile = True
+optionsProp = {}
